state property

String? get state

Implementation

String? get state => _jsObject.state;
set state (String? value)

A value included in the request that is also returned in the token response.

A randomly generated unique value is typically used for preventing cross site request forgery attacks. The state is also used to encode information about the user's state in the app before the authentication request occurred.

Implementation

set state(String? value) => _jsObject.state = value;